@@ -92,28 +92,31 @@ def sample_filter(data, x=10, n_reads=2):
 # =================== Other ====================
 # ==============================================
 
+# def estimate_k(data):
+#     """
+#     Estimate number of groups k:
+#         based on random matrix theory (RTM), borrowed from SC3
+#         input data is (p,n) matrix, p is feature, n is sample
+#     """
+#     p, n = data.shape
+#     if type(data) is not np.ndarray:
+#         data = data.toarray()
+#     x = scale(data)
+#     muTW = (np.sqrt(n-1) + np.sqrt(p)) ** 2
+#     sigmaTW = (np.sqrt(n-1) + np.sqrt(p)) * (1/np.sqrt(n-1) + 1/np.sqrt(p)) ** (1/3)
+#     sigmaHatNaive = x.T.dot(x)
+
+#     bd = np.sqrt(p) * sigmaTW + muTW
+#     evals = np.linalg.eigvalsh(sigmaHatNaive)
+
+#     k = 0
+#     for i in range(len(evals)):
+#         if evals[i] > bd:
+#             k += 1
+#     return k
+
 def estimate_k(data):
-    """
-    Estimate number of groups k:
-        based on random matrix theory (RTM), borrowed from SC3
-        input data is (p,n) matrix, p is feature, n is sample
-    """
-    p, n = data.shape
-    if type(data) is not np.ndarray:
-        data = data.toarray()
-    x = scale(data)
-    muTW = (np.sqrt(n-1) + np.sqrt(p)) ** 2
-    sigmaTW = (np.sqrt(n-1) + np.sqrt(p)) * (1/np.sqrt(n-1) + 1/np.sqrt(p)) ** (1/3)
-    sigmaHatNaive = x.T.dot(x)
-
-    bd = np.sqrt(p) * sigmaTW + muTW
-    evals = np.linalg.eigvalsh(sigmaHatNaive)
-
-    k = 0
-    for i in range(len(evals)):
-        if evals[i] > bd:
-            k += 1
-    return k
+    return min(data.shape[0]/100, 30)
 
 def get_decoder_weight(model_file):
     state_dict = torch.load(model_file)
